(no commit message)
[atyndall/cits2231.git] / scene.c
diff --git a/scene.c b/scene.c
index 3571fef..2f97ea1 100644 (file)
--- a/scene.c
+++ b/scene.c
@@ -464,20 +464,13 @@ void makeMenu() {
  * @param height New height\r
  */\r
 void windowReshape(int width, int height) {\r
-  glViewport(0, 0, (GLsizei)width, (GLsizei)height); \r
+  glViewport(0, 0, (GLsizei)width, (GLsizei)height);\r
+  printf("Width: %d, height: %d\n", width, height);\r
   glMatrixMode(GL_PROJECTION);\r
-  glLoadIdentity(); \r
-  \r
-  gluPerspective(60, (GLfloat)width / (GLfloat)height, 0.1, 1000.0);\r
-  \r
-  /*glViewport(0, 0, w, h);\r
-    glMatrixMode(GL_PROJECTION); /* switch matrix mode\r
-    glLoadIdentity();\r
-    if (w <= h)\r
-      gluOrtho2D(-2.0, 2.0, -2.0 * (GLfloat) h / (GLfloat) w, 2.0 * (GLfloat) h / (GLfloat) w);\r
-    else\r
-      gluOrtho2D(-2.0 * (GLfloat) w / (GLfloat) h, 2.0 * (GLfloat) w / (GLfloat) h, -2.0, 2.0);\r
-    glMatrixMode(GL_MODELVIEW); /* return to modelview mode */\r
+  glLoadIdentity();\r
+  gluPerspective( (60.0/500.0) * width, 1, 0.1, 1000.0);\r
+  glMatrixMode(GL_MODELVIEW);\r
+\r
 }\r
 \r
 /**\r
@@ -498,16 +491,9 @@ void display() {
    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);\r
    glLoadIdentity();\r
 \r
-   glTranslatef(0.0f,0.0f,-6.0f);                 // Move Left 1.5 Units And Into The Screen 6.0\r
-\r
+   glTranslatef(0.0f,0.0f,-10.0f); // Move into the Screen 10.0\r
 \r
-   glBegin(GL_QUADS);\r
-     glColor3f(1.0f,0.0f,0.0f);     // Set The Color To Red\r
-     glVertex3f(-1.0f, 1.0f, 0.0f); // Top left\r
-     glVertex3f( 1.0f, 1.0f, 0.0f); // Top Right\r
-     glVertex3f( 1.0f,-1.0f, 0.0f); // Bottom Right\r
-     glVertex3f(-1.0f,-1.0f, 0.0f); // Bottom Left\r
-   glEnd();\r
+   glutSolidTeapot(1);\r
 \r
    glutSwapBuffers();\r
 }\r

UCC git Repository :: git.ucc.asn.au